Installation and Getting Started
================================

**Pythons**: *Python* >= 3.4 (*PyPy* not tested yet).

**Platforms**: No platform-specific restrictions besides availability of communication (CAN-bus) drivers.

**Documentation**: `get latest <https://pyxcp.rtfd.org>`_.


Prerequisites
-------------

